==> open-xchange-documents-backend_7.4.2.orig.tar.bz2: open-xchange-documents-backend-7.4.2/com.openexchange.office.ooxml.xlsx/src/com/openexchange/office/ooxml/xlsx/tools/DrawingPic.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.office.ooxml.xlsx.tools;

import org.docx4j.dml.CTBlipFillProperties;
import org.docx4j.dml.spreadsheetdrawing.CTPicture;
import org.docx4j.dml.spreadsheetdrawing.CTPictureNonVisual;
import org.docx4j.openpackaging.parts.Part;
import org.json.JSONObject;
import com.openexchange.office.ooxml.drawingml.DMLHelper;

public class DrawingPic {

    public static void createProperties(JSONObject drawingProperties, Part part, CTPicture pic)
        throws Exception {

        CTPictureNonVisual pictureNonVisual = pic.getNvPicPr();
        if(pictureNonVisual!=null) {
            DMLHelper.createJsonFromNonVisualDrawingProperties(drawingProperties, pictureNonVisual.getCNvPr());
        }
        CTBlipFillProperties blipFillProperties = pic.getBlipFill();
        if(blipFillProperties!=null) {
            DMLHelper.createJsonFromBlipFillProperties(drawingProperties, pic.getBlipFill());
            drawingProperties.put("imageUrl", DMLHelper.getBlipUrl(part, blipFillProperties.getBlip()));
        }
        DMLHelper.createJsonFromShapeProperties(drawingProperties, pic.getSpPr());
    }
}

==> open-xchange-documents-backend_7.6.3.orig.tar.bz2: open-xchange-documents-backend-7.6.3/com.openexchange.office.ooxml.xlsx/src/com/openexchange/office/ooxml/xlsx/tools/DrawingPic.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.office.ooxml.xlsx.tools;

import org.docx4j.dml.CTBlipFillProperties;
import org.docx4j.dml.spreadsheetdrawing.CTPicture;
import org.docx4j.dml.spreadsheetdrawing.CTPictureNonVisual;
import org.docx4j.openpackaging.parts.Part;
import org.json.JSONObject;

import com.openexchange.office.ooxml.drawingml.DMLHelper;
import com.openexchange.office.ooxml.xlsx.OperationDocument;

public class DrawingPic {

    public static void createProperties(OperationDocument operationDocument, JSONObject attrs, Part part, CTPicture pic)
        throws Exception {

        CTPictureNonVisual pictureNonVisual = pic.getNvPicPr();
        if(pictureNonVisual!=null) {
            DMLHelper.createJsonFromNonVisualDrawingProperties(attrs, pictureNonVisual.getCNvPr());
        }
        CTBlipFillProperties blipFillProperties = pic.getBlipFill();
        if(blipFillProperties!=null) {
            DMLHelper.createJsonFromBlipFillProperties(part, attrs, pic.getBlipFill());
        }
        DMLHelper.createJsonFromShapeProperties(attrs, pic.getSpPr(), operationDocument.getTheme(), pic.getStyle(), true);
    }
}
